Model Code:

.. literalinclude:: /../../cis_interface/examples/formatted_io5/src/formatted_io5_modelA.py
   :language: python
   :linenos:

.. literalinclude:: /../../cis_interface/examples/formatted_io5/src/formatted_io5_modelB.py
   :language: python
   :linenos:


(`Example in other languages <examples/formatted_io5.html>`__)
